#!/bin/sh
# create dummy .i from each service present in /etc/rc.d/init.d

# blacklisted because either handled or not real service
blacklisted() {
	case "$s" in
	killall | single | cups | qmail | smbd | spamassassin)
		return 0
		;;
	esac
	return 1
}

add() {
	local s=$1
	local pkg=$2
	local svc=$3

	if [ -f $svc.i ]; then
		echo >&2 "Abort: $svc already exists!"
		exit 1
	fi

	network=$(grep /etc/sysconfig/network -c /etc/rc.d/init.d/$s)
	[ $network = 0 ] && network=
	echo -n "Creating $s ($pkg) as $svc${network:+ (requires network)}: "

	echo "%_initng_service_hook -p $pkg $svc" >> deps.spec
	sed -e '/./,/^$/!d' > $svc.i <<EOF
# Autogenerated by $0 on $(LC_ALL=C date)
service $svc {
	stdout = /dev/null;
	need = system/rundir${network:+ daemon/network};

	exec start = /etc/rc.d/init.d/$s start;
	exec stop = /etc/rc.d/init.d/$s stop;
}
EOF

	echo "OK"
}

if [ ! -d daemon ] && [ ! -d system ]; then
	echo >&2 "You must run this script from initng dir"
	exit 1
fi

for f in ${1:-$(find /etc/rc.d/init.d -type f -perm +100)}; do
	pkg=$(rpm --qf '%{name}\n' -qf $f 2>/dev/null | grep -v 'is not')
	[ "$pkg" ] || continue
	s=$(basename "$f")

	blacklisted && continue

	# skip direct match
	[ -f daemon/$s.i -o -f net/$s.i ] && continue

	svc="daemon/$s"

	# skip ones that are calling directly init.d script
	have=$(grep "init.d/$s " {net,daemon}/*.i | wc -l)
	[ $have -gt 0 ] && continue

	add $s $pkg $svc

	# running on real root. add it instantly
	if [ -f /etc/initng/$svc.i ]; then
		ng-update add $svc
	fi
done
